@@ -250,6 +250,17 @@ namespace Evolution {
 				e_cal_component_set_uid (Handle, value);
 			}
 		}
+		
+		[DllImport("ecal")]
+			static extern CalComponentVType e_cal_component_get_vtype (IntPtr handle);
+
+		public CalComponentVType VType 
+		{
+			get
+			{
+				return e_cal_component_get_vtype (Handle);
+			}
+		}
 
 		[DllImport ("ecal")]
 			static extern IntPtr e_cal_component_get_id (IntPtr handle);
@@ -356,6 +367,23 @@ namespace Evolution {
 				e_cal_component_set_status (Handle, (int) value);
 			}
 		}
+		
+		[DllImport("ecal")]
+			static extern int e_cal_component_get_percent_as_int (IntPtr raw);
+		[DllImport("ecal")]
+			static extern void e_cal_component_set_percent_as_int (IntPtr raw, int percent);
+
+		public int Percent
+		{
+			get
+			{
+				return e_cal_component_get_percent_as_int (Handle);
+			}
+			set
+			{
+				e_cal_component_set_percent_as_int (Handle, value);
+			}
+		}
 
 		[DllImport("evolutionglue")]
 			static extern int e_cal_component_get_priority2 (IntPtr raw);
@@ -498,6 +526,24 @@ namespace Evolution {
 				Marshal.FreeHGlobal (native_dt);
 			}
 		}
+		
+		public CalComponentDateTime DueDate {
+			get {
+				CalComponentDateTime dt = new CalComponentDateTime ();
+				IntPtr native_dt = GLib.Marshaller.StructureToPtrAlloc (dt);
+				e_cal_component_get_due (Handle, native_dt);
+				dt = (CalComponentDateTime) Marshal.PtrToStructure (native_dt, typeof (CalComponentDateTime));
+				Marshal.FreeHGlobal (native_dt);
+				
+				return dt;
+			}
+			set {	
+				IntPtr native_dt = GLib.Marshaller.StructureToPtrAlloc (value);
+				e_cal_component_set_due (Handle, native_dt);
+				Marshal.FreeHGlobal (native_dt);
+			}
+		}
+
 
 #endif		
 
@@ -994,6 +1040,6 @@ namespace Evolution {
 
 		return ret;
 	    }
-	}
 #endif
+	}
 }
